Name:       nodejs
Version:    0.4.12
Release:    5%{?dist}
Summary:    Evented I/O for V8 JavaScript
License:    BSD and MIT and ASL 2.0 and GPLv3
URL:        http://nodejs.org/
Source0:    http://nodejs.org/dist/node-v%{version}.tar.gz
BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# RPM macros for node.js library packages
Source1:    macros.nodejs

# EV_MULTIPLICITY=0 breaks shared libev
# http://groups.google.com/group/nodejs/browse_thread/thread/9665139b513da620
Patch1:     %{name}-ev_multiplicity.patch

# fix the man page to reflect the moved binary
Patch2:     %{name}-man.patch

# fix cmake to use shared libeio and libhttp_parser libs
#Patch3:     %%{name}-sharedlibs.patch

# force node to use /usr/lib/nodejs as the systemwide module directory
Patch4:     %{name}-libpath.patch

# use /usr/lib64/nodejs as an arch-specific module dir when appropriate
Patch5:     %{name}-lib64path.patch

# use jsmin.py from v8-devel, not bundled v8
#Patch6:     %%{name}-jsmin.patch

# use proper include directory
Patch7:     %{name}-includedir.patch

# make waf import from correct directory
Patch8:     %{name}-wafimport.patch

# make modules build properly with WAF
Patch9:     %{name}-waf-modules.patch

BuildRequires:  cmake
BuildRequires:  python
BuildRequires:  dos2unix
BuildRequires:  v8-devel
BuildRequires:  openssl-devel
BuildRequires:  c-ares-devel
BuildRequires:  libev-devel
#BuildRequires:  http-parser-devel
#BuildRequires:  libeio-devel

%description
Node.js is a server-side JavaScript environment that uses an asynchronous
event-driven model.  Node's goal is to provide an easy way to build scalable
network programs.

%package devel
Summary:    Evented I/O for V8 JavaScript - development headers
Requires:   nodejs = %{version}-%{release}
Requires:   pkgconfig
Requires:   libev-devel v8-devel c-ares-devel

%description devel
Node.js is a server-side JavaScript environment that uses an asynchronous
event-driven model.  Node's goal is to provide an easy way to build scalable
network programs.

This package contains the development headers, RPM macros, and a copy of the
built-in modules for nodejs.

%package doc
Summary:    Evented I/O for V8 JavaScript - documentation
BuildArch:  noarch

%description doc
Node.js is a server-side JavaScript environment that uses an asynchronous
event-driven model.  Node's goal is to provide an easy way to build scalable
network programs.

This package contains the documentation for nodejs.

%package waf
Summary:   Evented I/O for V8 JavaScript - customized WAF build system
BuildArch: noarch
Requires:  nodejs = %{version}-%{release}

%description waf
Node.js is a server-side JavaScript environment that uses an asynchronous
event-driven model.  Node's goal is to provide an easy way to build scalable
network programs.

This package contains the customized version of the WAF build system used by
Node.js and many of its modules.

%prep
%setup -q -n node-v%{version}
%patch1
#%%patch3
#%%patch6
%patch7
%patch8
%patch9

%if %{_lib} == "lib64"
%patch5
%else
%patch4
%endif

%patch2
mv doc/node.1 doc/nodejs.1

# partially generated HTML docs in the tarball prevent regenerating them from
# Markdown during build
rm -rf doc/api/api

# remove bundled dependencies
#rm -rf deps

%build
CFLAGS="${CFLAGS:-%optflags}" ; export CFLAGS ;
CXXFLAGS="${CXXFLAGS:-%optflags}" ; export CXXFLAGS ;
FFLAGS="${FFLAGS:-%optflags}" ; export FFLAGS ;

# NOT autoconf so dont use macro
./configure     \
        --prefix=%{_prefix}     \
        --shared-v8     \
        --shared-cares  \
        --shared-libev  \
        --shared-libev-includes=%{_includedir}/libev

make %{?_smp_mflags}
make doc

%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

# gzip man page and put it where it belongs
gzip doc/nodejs.1
mkdir -p %{buildroot}%{_mandir}/man1
cp -p doc/nodejs.1.gz %{buildroot}%{_mandir}/man1/
rm doc/nodejs.1.gz

# get rid of the markdown source files
rm doc/api/*.markdown

# fix EOL encodings on a couple files in docs
dos2unix doc/sh_main.js

# don't conflict with node
pushd %{buildroot}
mv .%{_bindir}/node .%{_bindir}/nodejs
mv .%{_includedir}/node .%{_includedir}/nodejs
mv ./usr/lib/node ./usr/lib/nodejs
popd

# create library directories
mkdir -p %{buildroot}%{_libdir}/nodejs/.npm

%if %{_lib} == "lib64"
mkdir -p %{buildroot}%{_libdir}/../lib/nodejs/.npm
%endif

# install RPM macros
mkdir -p %{buildroot}%{_sysconfdir}/rpm/
install -pm644 %{SOURCE1} %{buildroot}%{_sysconfdir}/rpm/

# fix include dir location in pkgconfig
sed -i 's/include\/node/include\/nodejs/g' \
                            %{buildroot}%{_libdir}/../lib/pkgconfig/nodejs.pc

# link to library include files that are typically bundled
ln -s ../libev/ev.h %{buildroot}%{_includedir}/%{name}/
ln -s ../libev/event.h %{buildroot}%{_includedir}/%{name}/
ln -s ../libev/ev++.h %{buildroot}%{_includedir}/%{name}/
ln -s ../ares.h %{buildroot}%{_includedir}/%{name}/
ln -s ../ares_build.h %{buildroot}%{_includedir}/%{name}/
ln -s ../ares_dns.h %{buildroot}%{_includedir}/%{name}/
ln -s ../ares_rules.h %{buildroot}%{_includedir}/%{name}/
ln -s ../ares_version.h %{buildroot}%{_includedir}/%{name}/
ln -s ../v8-debug.h %{buildroot}%{_includedir}/%{name}/
ln -s ../v8.h %{buildroot}%{_includedir}/%{name}/
ln -s ../v8-preparser.h %{buildroot}%{_includedir}/%{name}/
ln -s ../v8-profiler.h %{buildroot}%{_includedir}/%{name}/
ln -s ../v8stdint.h %{buildroot}%{_includedir}/%{name}/
ln -s ../v8-testing.h %{buildroot}%{_includedir}/%{name}/

# nuke WAF
# rm -rf %%{buildroot}%%{_bindir}/node-waf
# rm -rf %%{buildroot}%%{_libdir}/../lib/node/

## disable tests, many require network and don't work on koji
#%%check
#cd build
#ctest

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%{_bindir}/nodejs
%{_mandir}/man1/nodejs.1.gz
%doc AUTHORS ChangeLog LICENSE README.md TODO

%dir %{_libdir}/nodejs
%dir %{_libdir}/nodejs/.npm

%if %{_lib} == "lib64"
%dir %{_libdir}/../lib/nodejs
%dir %{_libdir}/../lib/nodejs/.npm
%endif

%files devel
%defattr(-,root,root,-)
%{_includedir}/nodejs/
%config %{_sysconfdir}/rpm/macros.nodejs
%doc lib
%{_libdir}/../lib/pkgconfig/nodejs.pc

%files doc
%doc build/doc/*

%files waf
%{_bindir}/node-waf
%{_libdir}/../lib/nodejs/wafadmin/

%changelog
* Thu Oct 27 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.12-5
- fix building modules with WAF

* Tue Oct 25 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.12-4
- symlink to headers of libraries that are typically bundled
- fixes builds of some native modules
- -devel now Requires v8-devel and libev-devel
- fix Requires on -waf

* Tue Oct 25 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.12-3
- import WAF from the correct directory

* Mon Oct 24 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.12-2
- ship a node-waf package with Node.js' customized WAF build system

* Sun Sep 25 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.12-1
- new upstream release 0.4.12
- set include directory properly
- disable tests, many don't work on koji due to lack of network
- use bundled libs so it actually works (targeting external repo)
- revert to WAF

* Thu Aug 25 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.11-3
- use jsmin.py from v8-devel, not the bundled v8
- rm -rf the bundled libraries
- fix broken nodejs_fixshebang macro in macros.nodejs

* Tue Aug 23 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.11-2
- cp man page instead of mv
- man page doesn't get doc macro
- disable broken tests

* Fri Aug 19 2011 T.C. Hollingsworth <tchollingsworth@gmail.com> - 0.4.11-1
- initial package
